unit TabbedFormwithNavigation;

interface

uses
  System.SysUtils, System.Types, System.UITypes, System.Classes, System.Variants,
  FMX.Types, FMX.Controls, FMX.Forms, FMX.Dialogs, FMX.TabControl, FMX.StdCtrls,
  System.Actions, FMX.ActnList, FMX.Sensors, FMX.WebBrowser, FMX.Edit,
  System.Sensors;

type
  TTabbedwithNavigationForm = class(TForm)
    TabControl1: TTabControl;
    tiMapa: TTabItem;
    tiDireccion: TTabItem;
    ActionList1: TActionList;
    TabControl2: TTabControl;
    TabItem5: TTabItem;
    ChangeTabAction1: TChangeTabAction;
    ToolBar1: TToolBar;
    lblTitle1: TLabel;
    ToolBar3: TToolBar;
    lblTitle3: TLabel;
    ChangeTabAction2: TChangeTabAction;
    tiRefresh: TTabItem;
    WebBrowser1: TWebBrowser;
    LocationSensor1: TLocationSensor;
    tiUbicacion: TTabItem;
    Label1: TLabel;
    edtDireccion: TEdit;
    Label2: TLabel;
    edtCp: TEdit;
    Label3: TLabel;
    edtCiudad: TEdit;
    wbMapa: TWebBrowser;
    SpeedButton2: TSpeedButton;
    procedure tiUbicacionClick(Sender: TObject);
    procedure tiRefreshClick(Sender: TObject);
    procedure LocationSensor1LocationChanged(Sender: TObject; const OldLocation,
      NewLocation: TLocationCoord2D);
    procedure SpeedButton1Click(Sender: TObject);
    procedure TabControl1Change(Sender: TObject);
  private
    MapLat, MapLon:Double;

    procedure CargarMapa(IniMap:Boolean=False; ADireccion:string='');
    procedure PosActualAleatoria();
  public
    constructor Create(AOwner: TComponent); override;
  end;

var
  TabbedwithNavigationForm: TTabbedwithNavigationForm;

implementation

{$R *.fmx}
{$R Mapa.res}

uses
  System.StrUtils;



procedure TTabbedwithNavigationForm.CargarMapa(IniMap:Boolean=False; ADireccion:string='');
var
  Str:String;
  StrLat, StrLon:string;
const
  INI_POS_LAT = '41.38119';
  INI_POS_LON = '2.12289';
  INI_ZOOM = 14;
begin


 // wbMapa.Navigate('file:///' + Str);
  StrLat := FloatToStr(MapLat);
  StrLat := AnsiReplaceText(StrLat, ',', '.');
  StrLon := FloatToStr(MapLon);
  StrLon := AnsiReplaceText(StrLon, ',', '.');

  if (IniMap) then begin
    Str := Format('https://maps.google.com/maps?q=%s,%s&z=%d',[INI_POS_LAT, INI_POS_LON, INI_ZOOM]);
  end
  else begin
    if (ADireccion <> '') then begin
      Str := 'https://maps.google.com/?q=' + ADireccion;
    end
    else begin
      Str := Format('http://maps.google.com/?q=%s,%s&z=%d',[StrLat, StrLon, 12]);
    end;
  end;

  //-ShowMessage(Str);

  wbMapa.Navigate(Str);
  wbMapa.Url := Str;
  wbMapa.Navigate();

end;

constructor TTabbedwithNavigationForm.Create(AOwner: TComponent);
begin
  inherited;
  MapLat := 0;
  MapLon := 0;
  Randomize;

  // Posicionar
  CargarMapa(True);
  // pestaa de mapa
  TabControl1.ActiveTab := tiMapa;

end;

procedure TTabbedwithNavigationForm.LocationSensor1LocationChanged(
  Sender: TObject; const OldLocation, NewLocation: TLocationCoord2D);
begin
  MapLat := NewLocation.Latitude;
  MapLon := NewLocation.Longitude;
end;

procedure TTabbedwithNavigationForm.PosActualAleatoria();
var
  str:String;
  flag:boolean;
  i:Double;
begin

  // ini
  flag := False;

  // activar el sensor...  (localizacin actual0)
  LocationSensor1.Active := True;
  // Queda desactivado?   ==> simulacin...
  if (not LocationSensor1.Active) then begin
    MapLat := 37 + (Random * 5);
    MapLon := Random * 3;
    i := Random;
    if (i > 0.5) then MapLon := MapLon * -1;

  end
  else begin
    // Esperamos...
    while not flag do begin
      Sleep(100);

      if (MapLat = 0) and (MapLon = 0) then begin
        Break;
      end;
    end;
    // Estn a cero?
    if (MapLat = 0) and (MapLon = 0) then begin
      MapLat := 37 + (Random * 5);
      MapLon := Random * 3;
      i := Random;
      if (i > 0.5) then MapLon := MapLon * -1;
    end;
  end;

  // Posicionar
  CargarMapa();

end;

procedure TTabbedwithNavigationForm.SpeedButton1Click(Sender: TObject);
var
  str:string;
begin

  // Comprobar los datos
  if (edtCp.Text = '') and (edtCiudad.Text = '') and (edtDireccion.Text = '') then begin
    ShowMessage('Debe rellenar algn dato para realizar la bsqueda');
    Exit;
  end;

  // Direccion
  if (edtDireccion.Text <> '') then begin
    Str := edtDireccion.Text;
  end;
  // CP?
  if (edtCp.Text <> '') then begin
    if (Str <> '') then Str := Str + ',';
    Str := Str + edtCp.Text;
  end;
  // Ciudad?
  if (edtCiudad.Text <> '') then begin
    if (Str <> '') then Str := Str + ',';
    Str := Str + edtCiudad.Text;
  end;

  // Posicionar
  CargarMapa(False, Str);
  // pestaa de mapa
  TabControl1.ActiveTab := tiMapa;
end;


procedure TTabbedwithNavigationForm.TabControl1Change(Sender: TObject);
begin
  if (TabControl1.ActiveTab = tiDireccion) then begin
    edtCp.Text := '';
    edtCiudad.Text := '';
    edtDireccion.Text := '';
    edtDireccion.SetFocus;
  end;
end;

procedure TTabbedwithNavigationForm.tiRefreshClick(Sender: TObject);
begin
  // cambiar a la primera pestaa
  TabControl1.ActiveTab :=  tiMapa;
  wbMapa.Navigate(wbMapa.URL);
end;

procedure TTabbedwithNavigationForm.tiUbicacionClick(Sender: TObject);
begin

  // Calcular posicion
  PosActualAleatoria();

  // cambiar a la primera pestaa
  TabControl1.ActiveTab := tiMapa;
end;

end.
